@@ -779,8 +779,8 @@ def interactive_imshow(
         aspect=aspect,
         interpolation=interpolation,
         alpha=callable_else_value_no_cast(alpha, param_excluder(params, "alpha")),
-        vmin=callable_else_value(vmin, param_excluder(params, "vmin")),
-        vmax=callable_else_value(vmax, param_excluder(params, "vmax")),
+        vmin=callable_else_value_no_cast(vmin, param_excluder(params, "vmin")),
+        vmax=callable_else_value_no_cast(vmax, param_excluder(params, "vmax")),
         origin=origin,
         extent=extent,
         filternorm=filternorm,
